@@ -1,4 +1,4 @@
-test_that('Three class format', {
+test_that("Three class format", {
   lst <- data_three_class()
   three_class <- lst$three_class
   three_class_tb <- lst$three_class_tb
@@ -7,12 +7,12 @@ test_that('Three class format', {
   storage.mode(three_class_tb) <- "double"
 
   expect_identical(
-   conf_mat(three_class, truth = "obs", estimate = "pred", dnn = c("", ""))$table,
-   three_class_tb
- )
+    conf_mat(three_class, truth = "obs", estimate = "pred", dnn = c("", ""))$table,
+    three_class_tb
+  )
 })
 
-test_that('Summary method', {
+test_that("Summary method", {
   lst <- data_three_class()
   three_class <- lst$three_class
   three_class_tb <- lst$three_class_tb
@@ -22,9 +22,11 @@ test_that('Summary method', {
 
   expect_equal(
     sum_obj_3$.metric,
-    c("accuracy", "kap", "sens", "spec", "ppv", "npv", "mcc", "j_index",
+    c(
+      "accuracy", "kap", "sens", "spec", "ppv", "npv", "mcc", "j_index",
       "bal_accuracy", "detection_prevalence", "precision", "recall",
-      "f_meas")
+      "f_meas"
+    )
   )
 
   expect_equal(
@@ -34,9 +36,11 @@ test_that('Summary method', {
 
   expect_equal(
     sum_obj_2$.metric,
-    c("accuracy", "kap", "sens", "spec", "ppv", "npv", "mcc", "j_index",
+    c(
+      "accuracy", "kap", "sens", "spec", "ppv", "npv", "mcc", "j_index",
       "bal_accuracy", "detection_prevalence", "precision", "recall",
-      "f_meas")
+      "f_meas"
+    )
   )
 
   expect_equal(
@@ -45,7 +49,7 @@ test_that('Summary method', {
   )
 })
 
-test_that('Summary method - estimators pass through', {
+test_that("Summary method - estimators pass through", {
   lst <- data_three_class()
   three_class <- lst$three_class
 
@@ -78,7 +82,6 @@ test_that("summary method - `event_level` passes through (#160)", {
 })
 
 test_that("Grouped conf_mat() handler works", {
-
   hpc_g <- dplyr::group_by(hpc_cv, Resample)
   res <- conf_mat(hpc_g, obs, pred)
 
@@ -91,24 +94,23 @@ test_that("Grouped conf_mat() handler works", {
       dplyr::filter(Resample == "Fold01") %>%
       conf_mat(obs, pred)
   )
-
 })
 
-test_that('Multilevel table -> conf_mat', {
+test_that("Multilevel table -> conf_mat", {
   expect_identical(
     conf_mat(table(hpc_cv$pred, hpc_cv$obs, dnn = c("Prediction", "Truth"))),
     conf_mat(hpc_cv, obs, pred)
   )
 })
 
-test_that('Multilevel matrix -> conf_mat', {
+test_that("Multilevel matrix -> conf_mat", {
   expect_identical(
     conf_mat(as.matrix(table(hpc_cv$pred, hpc_cv$obs, dnn = c("Prediction", "Truth")))),
     conf_mat(hpc_cv, obs, pred)
   )
 })
 
-test_that('Tidy method', {
+test_that("Tidy method", {
   res <- tidy(conf_mat(hpc_cv, obs, pred))
 
   expect_equal(
@@ -120,7 +122,6 @@ test_that('Tidy method', {
     res$name[[1]],
     "cell_1_1"
   )
-
 })
 
 test_that("can change the dimnames names", {
@@ -205,10 +206,87 @@ test_that("`as.data.frame.table()` method is run on the underlying `table` objec
 
 test_that("`...` is deprecated with a warning", {
   skip_if(getRversion() <= "3.5.3", "Base R used a different deprecated warning class.")
-  local_lifecycle_warnings()
+  rlang::local_options(lifecycle_verbosity = "warning")
 
   expect_snapshot(conf_mat(two_class_example, truth, predicted, foo = 1))
 
   hpc_cv <- dplyr::group_by(hpc_cv, Resample)
   expect_snapshot(conf_mat(hpc_cv, obs, pred, foo = 1))
 })
+
+test_that("Errors are thrown correctly", {
+  lst <- data_three_class()
+  three_class <- lst$three_class
+  three_class$obs_rev <- three_class$obs
+  levels(three_class$obs_rev) <- rev(levels(three_class$obs))
+  three_class$onelevel <- factor(1)
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(three_class, truth = obs_rev, estimate = pred, dnn = c("", ""))
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(three_class, truth = onelevel, estimate = pred, dnn = c("", ""))
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(three_class, truth = onelevel, estimate = onelevel, dnn = c("", ""))
+  )
+})
+
+test_that("Errors are thrown correctly - grouped", {
+  lst <- data_three_class()
+  three_class <- lst$three_class
+  three_class$obs_rev <- three_class$obs
+  levels(three_class$obs_rev) <- rev(levels(three_class$obs))
+  three_class$onelevel <- factor(1)
+  three_class <- dplyr::group_by(three_class, pred)
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(three_class, truth = obs_rev, estimate = pred, dnn = c("", ""))
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(three_class, truth = onelevel, estimate = pred, dnn = c("", ""))
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(three_class, truth = onelevel, estimate = onelevel, dnn = c("", ""))
+  )
+})
+
+test_that("conf_mat()'s errors when wrong things are passes", {
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(two_class_example, not_truth, predicted)
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(two_class_example, truth, not_predicted)
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(
+      dplyr::group_by(two_class_example, truth),
+      truth = not_truth,
+      estimate = predicted
+    )
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    conf_mat(
+      dplyr::group_by(two_class_example, truth),
+      truth = truth,
+      estimate = not_predicted
+    )
+  )
+})
