@@ -1,4 +1,4 @@
-test_that('flat tables', {
+test_that("flat tables", {
   lst <- data_three_class()
   three_class <- lst$three_class
   three_class_tb <- lst$three_class_tb
@@ -12,5 +12,8 @@ test_that('flat tables', {
     c("cell_1_1", "cell_2_1", "cell_1_2", "cell_2_2")
   )
 
-  expect_error(yardstick:::flatten(three_class_tb[, 1:2]))
+  expect_snapshot(
+    error = TRUE,
+    yardstick:::flatten(three_class_tb[, 1:2])
+  )
 })
