@@ -133,6 +133,21 @@ test_that("multiclass macro / macro_weighted - case weights are applied correctl
   )
 })
 
+test_that("works with hardhat case weights", {
+  df <- two_class_example
+
+  imp_wgt <- hardhat::importance_weights(seq_len(nrow(df)))
+  freq_wgt <- hardhat::frequency_weights(seq_len(nrow(df)))
+
+  expect_no_error(
+    gain_capture_vec(df$truth, df$Class1, case_weights = imp_wgt)
+  )
+
+  expect_no_error(
+    gain_capture_vec(df$truth, df$Class1, case_weights = freq_wgt)
+  )
+})
+
 test_that("errors with class_pred input", {
   skip_if_not_installed("probably")
 
