@@ -67,6 +67,21 @@ test_that("roc_aunp() - `options` is deprecated", {
   )
 })
 
+test_that("works with hardhat case weights", {
+  df <- two_class_example
+
+  imp_wgt <- hardhat::importance_weights(seq_len(nrow(df)))
+  freq_wgt <- hardhat::frequency_weights(seq_len(nrow(df)))
+
+  expect_no_error(
+    roc_aunp_vec(df$truth, as.matrix(df[c("Class1", "Class2")]), case_weights = imp_wgt)
+  )
+
+  expect_no_error(
+    roc_aunp_vec(df$truth, as.matrix(df[c("Class1", "Class2")]), case_weights = freq_wgt)
+  )
+})
+
 test_that("work with class_pred input", {
   skip_if_not_installed("probably")
 
